@@ -9,7 +9,7 @@ use Gtk2::Ex::DbLinker::DbcDataManager;
 use Data::Dumper;
 use Wx_dnav;
 
-use Wx::Event qw[EVT_TEXT EVT_COMBOBOX];
+#use Wx::Event qw[EVT_TEXT EVT_COMBOBOX];
 #EVT_LIST_ITEM_SELECTED EVT_COMBOBOX EVT_LISTBOX EVT_CHECKBOX EVT_BUTTON];
 
 use Wx qw[:everything];
@@ -36,11 +36,13 @@ $self->{log}->debug(" new form ");
 
   $self->{dnav}->load_panel("m_panel_for_content", $path,  "m_panel1"); 
   $self->{dnav}->frame->SetBackgroundColour(wxLIGHT_GREY);
+
+  $self->{dnav}->populate_widgets($top_panel, [qw(b_add b_apply)]);
+
+ $self->{log}->debug("sform - populate_widgets 2d: " . join(" ", map {$_->GetName}  @{$self->{dnav}->{w2disable}}));		
+ $self->{log}->debug("sform - populate_widgets: 2e: " . join(" ", map {$_->GetName}  @{$self->{dnav}->{w2enable}}));		
+
    
-  $self->{dnav}->populate_widgets($top_panel, [qw(b_add b_apply langid)]);
-
-  $self->{log}->debug("populate_widgets: " . join(" ", map {$_->GetName}  @{$self->{dnav}->{w2disable}}));
-
 	my $rs = $self->{schema}->resultset('Speak')->search_rs({countryid => $self->{countryid}}, {columns => ['countryid', 'langid', {langid1 => 'langid'}]});
 # (Dumper $rs->as_query);
 #die $rs->count;
@@ -48,11 +50,8 @@ $self->{log}->debug(" new form ");
 	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new({
 			rs => $rs,
 			});
-#die  $dman->get_field('langid');		
-#$dman->first;
-#$dman->get_field('langid1');
 
-	$self->{sform} = Wx::Perl::DbLinker::Wxform->new({
+		$self->{sform} = Wx::Perl::DbLinker::Wxform->new({
 		data_manager => $dman,
 		builder => $self->{dnav},
 		datawidgets => [qw(countryid langid langid1)],
@@ -64,16 +63,6 @@ $self->{log}->debug(" new form ");
 		after_update => sub{ on_after_update($self, $self->{dnav}, $dman, "form"); },
 			});
 
-	# $self->{dnav}->set_form($self->{sform});
-
-
-#	 $sf_dnav->connect_signal_for("langid", \&on_langid_changed, $self);
-#my $w =  $self->{dnav}->get_object('langid');
-#EVT_COMBOBOX($top_panel, $w, sub {print "evt_Combo\n";});
-# my $w =  $self->{dnav}->get_object('langid');
-# on_langid_changed($w, $self, @_);
-#EVT_TEXT($top_panel, $w, sub{ print "evt_text_from_combo\n"; });
-#die unless defined $sf_dnav->get_object('langid2');
 		my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new({
 				rs => $self->{schema}->resultset('Langue')->search_rs(undef, {order_by => 'langue' }),
 				#{columns => ['langue', {langid2 => 'langid'}],
@@ -104,7 +93,7 @@ $self->{log}->debug(" new form ");
 		
 		$self->{sf_list}->{dnav} = Wx_dnav->new({ismain=>0, frame => $top_panel});
 		$self->{sf_list}->{dnav}->populate_widgets($top_panel, [qw(b_add b_apply)]);
-		$self->{log}->debug("populate_widgets: " . join(" ", map {$_->GetName}  @{$self->{sf_list}->{dnav}->{w2disable}}));
+		$self->{log}->debug("grid - populate_widgets: " . join(" ", map {$_->GetName}  @{$self->{sf_list}->{dnav}->{w2disable}}));
 
 		#fieldnames => ["countryid", "country"],
 
@@ -134,13 +123,13 @@ $self->{log}->debug(" new form ");
 		$self->{sf_list}->{dnav}->connect_signal_for("b_add",\&on_add_lst_clicked, $self);
 
 		$self->{grid}->update; 
-
-		 $self->{sform}->add_childform($self->{grid});
+		 
+		$self->{sform}->add_childform($self->{grid});
 
 		 # on_countryid_changed($self, $self->{sform}->get_widget_value('countryid'));
 		 # $sf_dnav->show_all_except([]);
 		 
-
+		$self->{dnav}->show_all_except([qw(langid1 countryid)]);
    		$self->{dnav}->connect_signal_for("b_add", \&on_add_clicked, $self );
    		$self->{dnav}->connect_signal_for("b_delete", \&on_delete_clicked, $self );
    		$self->{dnav}->connect_signal_for("b_apply", \&on_apply_clicked, $self );
@@ -222,6 +211,7 @@ sub on_add_clicked {
     #die Dumper ($self->{countryid});
     $self->{sform}->insert;
     $self->{sform}->set_widget_value("countryid",$self->{countryid});
+    $self->{dnav}->get_object("langid")->Enable(1);
     
 }
 
@@ -230,9 +220,13 @@ sub on_apply_clicked {
     my ($b, $self) = @_;
      my  $c = $self->{sform}->get_widget_value('countryid');
      return unless ($c ne "");
-    $self->{log}->debug("sform_apply country : " . $self->{countryid} . " langue : " .  $self->{sform}->get_widget_value('langid') );
+     my $value =  $self->{sform}->get_widget_value('langid');
+    $self->{log}->debug("sform_apply country : " . $self->{countryid} . " langue : " .  $value );
+    $self->{sform}->set_widget_value("langid1", $value);
     $self->{sform}->apply;
     $self->{sform}->update;
+  	$self->{grid}->get_data_manager->query(  $self->{schema}->resultset('Speak')->search_rs({langid => $value, countryid => {'!=' => $self->{countryid}} }) );
+	$self->{grid}->update;
 }
 
 
