@@ -462,7 +462,7 @@ sub populate_widgets {
 		}
 
 	}
-	my %class =  map { $_, 1} qw(Wx::TextCrl Wx::ComboBox Wx::ListBox Wx::Button Wx::SpinCtrl Wx::Static::Text Wx::CheckBox Wx::SpinButton);
+	my %class =  map { $_, 1} qw(Wx::TextCtrl Wx::ComboBox Wx::ListBox Wx::Button Wx::SpinCtrl Wx::Static::Text Wx::CheckBox Wx::SpinButton);
 
  	return unless (UNIVERSAL::isa($w, 'Wx::Window'));
 	 my @c = $w->GetChildren;
