@@ -250,7 +250,7 @@ sub _setup_grid {
 				    my $text = $self->{combo_val}->{$field->{name} }->[$pos];
 				    # combo_cur contient l'id de la derniere ligne affichee de la grid
 				    # $self->{combo_cur}->{$field->{name}} = $self->{combo_id}->{ $field->{name} }->[$pos];
-				    $self->{log}->debug( $field->{name}, " id: ", $id, " text: ", $text);
+				    #$self->{log}->debug( $field->{name}, " id: ", $id, " text: ", $text);
 					#$self->{combo_cur}->{ $field->{name} } est un array ref des id sous-jacents aux lignes affichees
 				    my $aref = $self->{combo_cur}->{ $field->{name} };
 				    push @$aref, $id;
@@ -268,7 +268,7 @@ sub _setup_grid {
 				 
 			}
 			
-			$self->{log}->debug("set cell renderer ", $ed_ref, " row: ", $r, " col: ", $col);
+			#$self->{log}->debug("set cell renderer ", $ed_ref, " row: ", $r, " col: ", $col);
 			
 			if ($field->{editor_ro}){ 
 				$self->SetReadOnly($r, $col, 1);
@@ -325,7 +325,7 @@ sub _setup_combo {
   for (my $row_pos = 0; $row_pos < $last ; $row_pos ++ ) {
         
      
-	$self->{log}->debug("Datasheet setupcombo set row pos " . $row_pos);
+	  #$self->{log}->debug("Datasheet setupcombo set row pos " . $row_pos);
 	$dman->set_row_pos( $row_pos );
 
 	#push @model_row, $model->append;
